@@ -1,6 +1,6 @@
 /* Self tests for the TUI
 
-   Copyright (C) 2019 Free Software Foundation, Inc.
+   Copyright (C) 2019-2025 Free Software Foundation, Inc.
 
    This file is part of GDB.
 
@@ -17,12 +17,12 @@
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
-#include "defs.h"
 #include "gdbsupport/selftest.h"
-#include "tui/tui-winsource.h"
 
 #ifdef TUI
 
+#include "tui/tui-winsource.h"
+
 namespace selftests {
 namespace tui {
 
@@ -30,13 +30,13 @@ static void
 run_tests ()
 {
   const char *text = "hello";
-  std::string result = tui_copy_source_line (&text, 0, 0, 50, 0);
+  std::string result = tui_copy_source_line (&text);
   SELF_CHECK (result == "hello");
   SELF_CHECK (*text == '\0');
 
   text = "hello\n";
-  result = tui_copy_source_line (&text, 0, 0, 3, 0);
-  SELF_CHECK (result == "hel");
+  result = tui_copy_source_line (&text);
+  SELF_CHECK (result == "hello");
   SELF_CHECK (*text == '\0');
 }
 
@@ -45,8 +45,7 @@ run_tests ()
 
 #endif /* TUI */
 
-void
-_initialize_tui_selftest ()
+INIT_GDB_FILE (tui_selftest)
 {
 #ifdef TUI
   selftests::register_test ("tui", selftests::tui::run_tests);
